Introduction
============

.. image:: _static/logo.png
   :width: 800px
   :align: center

.. raw:: html

   <br><br>

.. list-table::
   :widths: auto
   :header-rows: 1

   * - Category
     - Badges
   * - **Testing**
     - .. image:: https://github.com/nathanramoscfa/pyeconomics/actions/workflows/tests.yml/badge.svg
          :target: https://github.com/nathanramoscfa/pyeconomics/actions/workflows/tests.yml
       .. image:: https://codecov.io/gh/nathanramoscfa/pyeconomics/graph/badge.svg?token=I1CRHDN73S
          :target: https://codecov.io/gh/nathanramoscfa/pyeconomics
   * - **Package**
     - .. image:: https://img.shields.io/pypi/v/pyeconomics.svg
          :target: https://pypi.org/project/pyeconomics/
       .. image:: https://img.shields.io/pypi/pyversions/pyeconomics
       .. image:: https://static.pepy.tech/badge/pyeconomics
          :target: https://pepy.tech/project/pyeconomics
       .. image:: https://img.shields.io/badge/License-MIT-brightgreen.svg
          :target: https://opensource.org/licenses/MIT
   * - **Documentation**
     - .. image:: https://readthedocs.org/projects/pyeconomics/badge/?version=latest
          :target: https://pyeconomics.readthedocs.io/en/latest/?badge=latest
   * - **Release**
     - .. image:: https://github.com/nathanramoscfa/pyeconomics/actions/workflows/release.yml/badge.svg
          :target: https://github.com/nathanramoscfa/pyeconomics/actions/workflows/release.yml
   * - **Build Status**
     - .. image:: https://github.com/nathanramoscfa/pyeconomics/actions/workflows/tests.yml/badge.svg
          :target: https://github.com/nathanramoscfa/pyeconomics/actions/workflows/tests.yml
   * - **Maintainability**
     - .. image:: https://api.codeclimate.com/v1/badges/8d0d8b5a5bed8fe94814/maintainability
          :target: https://codeclimate.com/github/nathanramoscfa/pyeconomics/maintainability
   * - **Code Style**
     - .. image:: https://img.shields.io/badge/code%20style-flake8-brightgreen.svg
          :target: https://github.com/PyCQA/flake8
   * - **Dependencies**
     - .. image:: https://img.shields.io/librariesio/github/nathanramoscfa/pyeconomics
          :target: https://libraries.io/github/nathanramoscfa/pyeconomics
   * - **Security**
     - .. image:: https://snyk.io/test/github/nathanramoscfa/pyeconomics/badge.svg
          :target: https://snyk.io/test/github/nathanramoscfa/pyeconomics

PyEconomics is a versatile and comprehensive library that integrates various
economic and financial models. It is designed to support the development and
analysis of monetary policy rules, exchange rate models, macroeconomic and
microeconomic models, discounted cash flow models, and much more.
